@@ -10,8 +10,10 @@
 #   Copyright (C) 2004-2009, 2012, 2014 Steve Hay.  All rights reserved.
 #
 # LICENCE
-#   You may distribute under the terms of either the GNU General Public License
-#   or the Artistic License, as specified in the LICENCE file.
+#   This module is free software; you can redistribute it and/or modify it under
+#   the same terms as Perl itself, i.e. under the terms of either the GNU
+#   General Public License or the Artistic License, as specified in the LICENCE
+#   file.
 #
 #===============================================================================
 
@@ -31,7 +33,7 @@ use XSLoader qw();
 our($VERSION);
 
 BEGIN {
-    $VERSION = '2.07';
+    $VERSION = '2.08';
 
     XSLoader::load(__PACKAGE__, $VERSION);
 }
@@ -170,10 +172,6 @@ been set-up with a crypt mode that it does not recognize.
 
 I<None>.
 
-=head1 KNOWN BUGS
-
-I<None>.
-
 =head1 SEE ALSO
 
 L<Filter::Crypto>;
@@ -195,7 +193,7 @@ decryption filter's SV working.
 
 =head1 AUTHOR
 
-Steve Hay E<lt>shay@cpan.orgE<gt>
+Steve Hay E<lt>L<shay@cpan.org|mailto:shay@cpan.org>E<gt>.
 
 =head1 COPYRIGHT
 
@@ -209,11 +207,11 @@ License or the Artistic License, as specified in the F<LICENCE> file.
 
 =head1 VERSION
 
-Version 2.07
+Version 2.08
 
 =head1 DATE
 
-28 Feb 2015
+31 Jul 2018
 
 =head1 HISTORY
 
